# console-browserify change log

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](http://semver.org/).

## 1.2.0
* Move to the browserify org.
* Remove `date-now` dependency. ([@jakepusateri](https://github.com/jakepusateri) in [#10](https://github.com/browserify/console-browserify/pull/10))
* Fix memory leak in `time`/`timeEnd`. ([@maxnordlund](https://github.com/maxnordlund) in [#11](https://github.com/browserify/console-browserify/pull/11))
